==> ht_0.5.0.orig.tar.gz: ht-0.5.0/pestruct.cc <==
/* 
 *	HT Editor
 *	pestruct.cc
 *
 *	Copyright (C) 1999, 2000, 2001 Stefan Weyergraf (stefan@weyergraf.de)
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2 as
 *	published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "global.h"
#include "htendian.h"
#include "pestruct.h"
#include "coff_s.h"

byte PE_DATA_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};


byte PE_OPTIONAL_HEADER32_NT_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};


byte PE_EXPORT_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_THUNK_DATA_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_IMPORT_DESCRIPTOR_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_DELAY_IMPORT_DESCRIPTOR_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DIRECTORY_ENTRY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DATA_ENTRY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

==> ht_0.7.3.orig.tar.gz: ht-0.7.3/pestruct.cc <==
/* 
 *	HT Editor
 *	pestruct.cc
 *
 *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2 as
 *	published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "global.h"
#include "htendian.h"
#include "pestruct.h"
#include "coff_s.h"

byte PE_DATA_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};


byte PE_OPTIONAL_HEADER32_NT_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_OPTIONAL_HEADER64_NT_struct[] = {
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};


byte PE_EXPORT_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_THUNK_DATA_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_THUNK_DATA_64_struct[] = {
	STRUCT_ENDIAN_QWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_IMPORT_DESCRIPTOR_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_DELAY_IMPORT_DESCRIPTOR_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DIRECTORY_ENTRY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};

byte PE_RESOURCE_DATA_ENTRY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};	

byte PE_IL_DIRECTORY_struct[] = {
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_WORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	STRUCT_ENDIAN_DWORD | STRUCT_ENDIAN_HOST,
	0
};
